/* **********************************************************************
    Copyright 2003 Rensselaer Polytechnic Institute.

    All worldwide rights reserved. A license to use, copy, modify and
    distribute this software for noncommercial research purposes only is
    hereby granted, provided that this copyright notice and accompanying
    disclaimer is not modified or removed from the software.

    DISCLAIMER: The software is distributed" AS IS" without any express or
    implied warranty, including but not limited to, any implied warranties
    of merchantability or fitness for a particular purpose or any warrant)'
    of non-infringement of any current or pending patent rights. The authors
    of the software make no representations about the suitability of this
    software for any particular purpose. The entire risk as to the quality
    and performance of the software is with the user. Should the software
    prove defective, the user assumes the cost of all necessary servicing,
    repair or correction. In particular, neither Rensselaer Polytechnic
    Institute, nor the authors of the software are liable for any indirect,
    special, consequential, or incidental damages related to the software,
    to the maximum extent the law permits.
*/

package edu.rpi.cct.uwcal.admin.admingroup;

import edu.rpi.cct.uwcal.admin.PEAbstractAction;
import edu.rpi.cct.uwcal.admin.PEActionForm;
import edu.rpi.cct.uwcal.webcommon.UWCalSession;

import edu.washington.cac.calfacade.shared.AdminGroups;
import edu.washington.cac.calfacade.shared.AdminGroupVO;

import javax.servlet.http.HttpServletRequest;

/** This action fetches an admin group
 *
 * <p>Forwards to:<ul>
 *      <li>"noAccess"     user not authorised.</li>
 *      <li>"notFound"     no such event.</li>
 *      <li>"continue"     continue on to update page.</li>
 * </ul>
 *
 * @author Mike Douglass   douglm@rpi.edu
 */
public class PEFetchAGAction extends PEAbstractAction {
  /** This is the routine which does the work.
   *
   * @param request   Needed to locate session
   * @param sess      UWCalSession calendar session object
   * @param form      Action form
   * @return String   forward name
   */
  public String doAction(HttpServletRequest request,
                         UWCalSession sess,
                         PEActionForm form) throws Throwable {
    /** Check access
     */
    if (!form.getUserAuth().isSuperUser()) {
      return "noAccess";
    }

    AdminGroups adgrps = form.getCalSvcI().getAdminGroups();
    form.assignChoosingGroup(false); // reset

    /** User requested an admin group from the list or by entering the name.
     */
    String name = request.getParameter("adminGroupName");
    if (name == null) {
      return "notFound";
    }

    AdminGroupVO ag = adgrps.findGroup(name);

    if (debug) {
      if (ag == null) {
        logIt("No group with name " + name);
      } else {
        logIt("Retrieved admin group " + ag.getName());
      }
    }

    if (ag == null) {
      return "notFound";
    }

    form.setUpdAdminGroup(ag);

    return "continue";
  }
}

