/* **********************************************************************
    Copyright 2005 Rensselaer Polytechnic Institute.

    All worldwide rights reserved. A license to use, copy, modify and
    distribute this software for noncommercial research purposes only is
    hereby granted, provided that this copyright notice and accompanying
    disclaimer is not modified or removed from the software.

    DISCLAIMER: The software is distributed" AS IS" without any express or
    implied warranty, including but not limited to, any implied warranties
    of merchantability or fitness for a particular purpose or any warrant)'
    of non-infringement of any current or pending patent rights. The authors
    of the software make no representations about the suitability of this
    software for any particular purpose. The entire risk as to the quality
    and performance of the software is with the user. Should the software
    prove defective, the user assumes the cost of all necessary servicing,
    repair or correction. In particular, neither Rensselaer Polytechnic
    Institute, nor the authors of the software are liable for any indirect,
    special, consequential, or incidental damages related to the software,
    to the maximum extent the law permits.
*/

package edu.rpi.cct.uwcal.caldav;

import edu.rpi.cct.uwcal.calsvci.CalSvcI;
import edu.rpi.cct.uwcal.icalendar.IcalTranslator;
import edu.rpi.cct.webdav.servlet.shared.WebdavIntfException;
import edu.rpi.cct.webdav.servlet.shared.WebdavNsNode;

import java.io.Reader;
import java.util.Collection;
import java.util.Vector;

/** Class to represent a caldav node.
 *
 *   @author Mike Douglass   douglm@rpi.edu
 */
public abstract class CaldavUWCalNode extends WebdavNsNode {
  protected String owner;

  protected CaldavURI cdURI;

  /* for accessing calendars */
  protected CalSvcI svci;

  protected IcalTranslator trans;

  CaldavUWCalNode(CaldavURI cdURI, CalSvcI svci, IcalTranslator trans,
                  boolean debug) {
    super(debug);

    this.cdURI = cdURI;
    this.svci = svci;
    this.trans = trans;

    this.uri = cdURI.getUri();
    this.owner = cdURI.getUserName();
  }

  /* ====================================================================
   *                         Public methods
   * ==================================================================== */

  public boolean isUser() {
    return cdURI.isUser();
  }

  public boolean isCalendar() {
    return cdURI.isCalendar();
  }

  public CaldavURI getCDURI() {
    return cdURI;
  }

  /** Return a collection of children objects. These will all be node objects.
   *
   * <p>Default is to return null
   */
  public Collection getChildren() throws WebdavIntfException {
    return null;
  }

  /** Return a collection of property objects
   *
   * <p>Default is to return an empty Collection
   *
   * @param ns      String interface namespace.
   * @return Collection (possibly empty) of WebdavProperty objects
   */
  public Collection getProperties(String ns) throws WebdavIntfException {
    return new Vector();
  }

  /** Returns an InputStream for the content.
   *
   * @return Reader       A reader for the content.
   */
  public Reader getContent() throws WebdavIntfException {
    return null;
  }

  /* ====================================================================
   *                   Abstract methods
   * ==================================================================== */

  public void setOwner() throws WebdavIntfException {
    throw new WebdavIntfException("Not allowed");
  }

  /** Should return a value suitable for insertion in the owner dav tag.
   */
  public String getOwner() throws WebdavIntfException {
    return owner;
  }

  /* ====================================================================
   *                   Object methods
   * ==================================================================== */

  public String toString() {
    StringBuffer sb = new StringBuffer(this.getClass().getName());

    sb.append("{");
    sb.append("cdURI=");
    sb.append(cdURI.toString());
    sb.append("}");

    return sb.toString();
  }
}
