/* **********************************************************************
    Copyright 2005 Rensselaer Polytechnic Institute.

    All worldwide rights reserved. A license to use, copy, modify and
    distribute this software for noncommercial research purposes only is
    hereby granted, provided that this copyright notice and accompanying
    disclaimer is not modified or removed from the software.

    DISCLAIMER: The software is distributed" AS IS" without any express or
    implied warranty, including but not limited to, any implied warranties
    of merchantability or fitness for a particular purpose or any warrant)'
    of non-infringement of any current or pending patent rights. The authors
    of the software make no representations about the suitability of this
    software for any particular purpose. The entire risk as to the quality
    and performance of the software is with the user. Should the software
    prove defective, the user assumes the cost of all necessary servicing,
    repair or correction. In particular, neither Rensselaer Polytechnic
    Institute, nor the authors of the software are liable for any indirect,
    special, consequential, or incidental damages related to the software,
    to the maximum extent the law permits.
*/

package edu.rpi.cct.webdav.servlet.common;

import edu.rpi.cct.webdav.servlet.shared.WebdavException;

import java.util.Collection;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/** Retrieve and process Webdav header values
 *
 *   @author Mike Douglass   douglm@rpi.edu
 */
public class Headers {
  protected final static int depthInfinity = Integer.MAX_VALUE;

  public static int depth(HttpServletRequest req) throws WebdavException {
    String depthStr = req.getHeader("Depth");

    if (depthStr == null) {
      return depthInfinity;
    }

    if (depthStr.equals("0")) {
      return 0;
    }

    if (depthStr.equals("1")) {
      return 1;
    }

    // Treat anything else as infinity?
    return depthInfinity;
  }

  public static boolean ifNoneMatchAny(HttpServletRequest req)
          throws WebdavException {
    String hdrStr = req.getHeader("If-None-Match");

    return "*".equals(hdrStr);
  }

  /** The following is instantiated for If headers
   */
  public static class IfHeaders {
    /* Only If-Match or If-None-Match are allowed not both
     */

  }
}

