/* **********************************************************************
    Copyright 2005 Rensselaer Polytechnic Institute.

    All worldwide rights reserved. A license to use, copy, modify and
    distribute this software for noncommercial research purposes only is
    hereby granted, provided that this copyright notice and accompanying
    disclaimer is not modified or removed from the software.

    DISCLAIMER: The software is distributed" AS IS" without any express or
    implied warranty, including but not limited to, any implied warranties
    of merchantability or fitness for a particular purpose or any warrant)'
    of non-infringement of any current or pending patent rights. The authors
    of the software make no representations about the suitability of this
    software for any particular purpose. The entire risk as to the quality
    and performance of the software is with the user. Should the software
    prove defective, the user assumes the cost of all necessary servicing,
    repair or correction. In particular, neither Rensselaer Polytechnic
    Institute, nor the authors of the software are liable for any indirect,
    special, consequential, or incidental damages related to the software,
    to the maximum extent the law permits.
*/

package edu.rpi.cct.webdav.servlet.shared;

import edu.rpi.sss.util.xml.QName;

import java.io.Serializable;
import java.util.Collection;
import java.util.Enumeration;

/** One of these for each property in a request.
 *
 *   @author Mike Douglass   douglm@rpi.edu
 */
public class WebdavProperty implements Serializable {
  private QName tag;
  private String pval;

  public WebdavProperty(QName tag,
                        String pval) {
    this.tag = tag;
    this.pval = pval;
  }

  public void setTag(QName val) {
    tag = val;
  }

  public QName getTag() {
    return tag;
  }

  public void setPval(String val) {
    pval = val;
  }

  public String getPval() {
    return pval;
  }

  /** Convenience method to provide an enumeration of these objects
   */
  public static Enumeration getEnumeration(Collection c) {
    WebdavProperty[] ps = (WebdavProperty[])c.toArray(
            new WebdavProperty[c.size()]);
    return new PropertyEnumeration(ps);
  }

  private static class PropertyEnumeration implements Enumeration {
    WebdavProperty[] ps = null;
    int index;

    public PropertyEnumeration(WebdavProperty[] ps) {
      this.ps = ps;
    }

    public boolean hasMoreElements() {
      if ((ps == null) ||
          (index >= ps.length)) {
        return false;
      }

      return true;
    }

    public Object nextElement() {
      if ((ps == null) ||
          (index >= ps.length)) {
        return null;
      }

      WebdavProperty p = ps[index];
      index++;

      return p;
    }
  }
}
