#
# @author Mike Douglass, Arlen Johnson, Greg Barnes, Cameron Mallory
# Bugfix by Jake Dolan
#
# Replacement for schema.mysql
#
# This file contains table create commands
# Initialization data can be found in mysqlInit.sql
# For the time being, comments about the schema structure
# can be found in schema.mysql
#
#	To load use something similar to:
#	mysql -u userName -p  dbName < mysql.sql
#
#	Be sure that dbName above matches the line below
#	that starts with USE

USE calendardb;

-- Database: calendardb
-- ------------------------------------------------------
-- Server version	4.0.20-standard

--
-- Table structure for table `adminGroupMembers`
--

DROP TABLE IF EXISTS adminGroupMembers;
CREATE TABLE adminGroupMembers (
  groupname varchar(255) default NULL,
  userid varchar(20) binary NOT NULL default '',
  KEY groupname (groupname),
  KEY userid (userid)
) TYPE=MyISAM;

--
-- Table structure for table `adminGroups`
--

DROP TABLE IF EXISTS adminGroups;
CREATE TABLE adminGroups (
  groupname varchar(255) NOT NULL default '',
  description blob,
  groupOwner varchar(20) binary NOT NULL default '',
  ownerid varchar(20) binary NOT NULL default '',
  PRIMARY KEY  (groupname),
  KEY groupname (groupname),
  KEY groupOwner (groupOwner),
  KEY ownerid (ownerid)
) TYPE=MyISAM;

--
-- Table structure for table `auth`
--

DROP TABLE IF EXISTS auth;
CREATE TABLE auth (
  userid int(11) NOT NULL default '0',
  usertype char(1) default NULL,
  lastname varchar(255) default NULL,
  firstname varchar(255) default NULL,
  phone varchar(255) default NULL,
  email varchar(255) default NULL,
  department varchar(255) default NULL,
  KEY aui (userid)
) TYPE=MyISAM;

--
-- Table structure for table `authorization`
--

DROP TABLE IF EXISTS authorization;
CREATE TABLE authorization (
  userid varchar(20) NOT NULL default '',
  usertype char(1) default NULL,
  lastname varchar(255) default NULL,
  firstname varchar(255) default NULL,
  phone varchar(255) default NULL,
  email varchar(255) default NULL,
  department varchar(255) default NULL
) TYPE=MyISAM;

--
-- Table structure for table `authprefKeywords`
--

DROP TABLE IF EXISTS authprefKeywords;
CREATE TABLE authprefKeywords (
  userid int(11) NOT NULL default '0',
  keywordid int(11) NOT NULL default '0',
  KEY apkui (userid)
) TYPE=MyISAM;

--
-- Table structure for table `authprefLocations`
--

DROP TABLE IF EXISTS authprefLocations;
CREATE TABLE authprefLocations (
  userid int(11) NOT NULL default '0',
  locationid int(11) NOT NULL default '0',
  KEY aplui (userid)
) TYPE=MyISAM;

--
-- Table structure for table `authprefSponsors`
--

DROP TABLE IF EXISTS authprefSponsors;
CREATE TABLE authprefSponsors (
  userid int(11) NOT NULL default '0',
  sponsorid int(11) NOT NULL default '0',
  KEY apsui (userid)
) TYPE=MyISAM;

--
-- Table structure for table `authprefs`
--

DROP TABLE IF EXISTS authprefs;
CREATE TABLE authprefs (
  userid int(11) NOT NULL default '0',
  autoaddKeywords char(1) NOT NULL default '',
  autoaddLocations char(1) NOT NULL default '',
  autoaddSponsors char(1) NOT NULL default '',
  KEY apui (userid)
) TYPE=MyISAM;

--
-- Table structure for table `bywhat`
--

DROP TABLE IF EXISTS bywhat;
CREATE TABLE bywhat (
  ruleid int(11) NOT NULL default '0',
  type char(1) NOT NULL default '',
  number int(11) NOT NULL default '0',
  KEY ruleid (ruleid)
) TYPE=MyISAM;

--
-- Table structure for table `calendars`
--

DROP TABLE IF EXISTS calendars;
CREATE TABLE calendars (
  calendarid int(11) NOT NULL auto_increment,
  name varchar(200) default NULL,
  type char(1) NOT NULL default '',
  ref_num int(11) NOT NULL default '0',
  parent int(11) NOT NULL default '0',
  PRIMARY KEY  (calendarid)
) TYPE=MyISAM;

--
-- Table structure for table `event_keywords`
--

DROP TABLE IF EXISTS event_keywords;
CREATE TABLE event_keywords (
  eventid int(11) NOT NULL default '0',
  keywordid int(11) NOT NULL default '0',
  KEY eventid (eventid),
  KEY keywordid (keywordid)
) TYPE=MyISAM;

--
-- Table structure for table `eventguids`
--

DROP TABLE IF EXISTS eventguids;
CREATE TABLE eventguids (
  eventid int(11) NOT NULL default '0',
  guid varchar(255) default NULL,
  KEY eguidi (eventid),
  KEY eguidg (guid)
) TYPE=MyISAM;

--
-- Table structure for table `eventnames`
--

DROP TABLE IF EXISTS eventnames;
CREATE TABLE eventnames (
  eventid int(11) NOT NULL default '0',
  evname varchar(255) NOT NULL default '',
  KEY enamei (eventid),
  KEY enamen (evname)
) TYPE=MyISAM;

--
-- Table structure for table `eventrefs`
--

DROP TABLE IF EXISTS eventrefs;
CREATE TABLE eventrefs (
  eventid int(11) NOT NULL default '0',
  userid int(11) NOT NULL default '0',
  purpose char(1) binary NOT NULL default 'E',
  KEY eventid (eventid),
  KEY userid (userid),
  KEY purpose (purpose)
) TYPE=MyISAM;

--
-- Table structure for table `events`
--

DROP TABLE IF EXISTS events;
CREATE TABLE events (
  eventid int(11) NOT NULL auto_increment,
  lastmod timestamp(14) NOT NULL,
  seq int(11) NOT NULL default '0',
  publicf char(1) default NULL,
  created datetime NOT NULL default '0000-00-00 00:00:00',
  startdate date NOT NULL default '0000-00-00',
  starttime time default NULL,
  enddate date NOT NULL default '0000-00-00',
  endtime time default NULL,
  shortdesc varchar(255) binary NOT NULL default '',
  longdesc blob,
  longdesc1 blob,
  longdesc2 blob,
  link varchar(255) binary default NULL,
  status char(1) binary NOT NULL default 'F',
  locationid int(11) NOT NULL default '0',
  sponsorid int(11) NOT NULL default '0',
  creator varchar(20) binary NOT NULL default '',
  recurring_status char(1) binary NOT NULL default 'N',
  cost varchar(255) binary default NULL,
  PRIMARY KEY  (eventid),
  KEY public (publicf),
  KEY startdate (startdate),
  KEY enddate (enddate),
  KEY shortdesc (shortdesc(10)),
  KEY status (status),
  KEY locationid (locationid),
  KEY sponsorid (sponsorid),
  KEY creator (creator),
  KEY startdate_2 (startdate,enddate)
) TYPE=MyISAM;

--
-- Table structure for table `keyword_attrs`
--

DROP TABLE IF EXISTS keyword_attrs;
CREATE TABLE keyword_attrs (
  kaid int(11) NOT NULL auto_increment,
  kakeywordid int(11) NOT NULL default '0',
  kaname varchar(255) binary NOT NULL default '',
  kaval varchar(255) binary NOT NULL default '',
  PRIMARY KEY  (kaid),
  KEY kakeywordid (kakeywordid),
  KEY kaname (kaname),
  KEY kaval (kaval)
) TYPE=MyISAM;

--
-- Table structure for table `keywords`
--

DROP TABLE IF EXISTS keywords;
CREATE TABLE keywords (
  keywordid int(11) NOT NULL auto_increment,
  word varchar(255) binary NOT NULL default '',
  longdesc blob,
  longdesc1 blob,
  creator varchar(20) binary NOT NULL default '',
  publicf char(1) default NULL,
  PRIMARY KEY  (keywordid),
  KEY word (word(10)),
  KEY creator (creator),
  KEY public (publicf)
) TYPE=MyISAM;

--
-- Table structure for table `lastmods`
--

DROP TABLE IF EXISTS lastmods;
CREATE TABLE lastmods (
  name varchar(255) NOT NULL default '',
  lastmod timestamp(14) NOT NULL,
  PRIMARY KEY  (name)
) TYPE=MyISAM;

--
-- Table structure for table `locations`
--

DROP TABLE IF EXISTS locations;
CREATE TABLE locations (
  locationid int(11) NOT NULL auto_increment,
  address varchar(255) binary NOT NULL default '',
  subaddress varchar(255) binary default NULL,
  link varchar(255) binary default NULL,
  creator varchar(20) binary NOT NULL default '',
  publicf char(1) default NULL,
  PRIMARY KEY  (locationid),
  KEY address (address),
  KEY creator (creator),
  KEY public (publicf)
) TYPE=MyISAM;

--
-- Table structure for table `master_details`
--

DROP TABLE IF EXISTS master_details;
CREATE TABLE master_details (
  detailid int(11) NOT NULL auto_increment,
  master_eventid int(11) NOT NULL default '0',
  startdate date NOT NULL default '0000-00-00',
  starttime time default NULL,
  enddate date NOT NULL default '0000-00-00',
  endtime time default NULL,
  PRIMARY KEY  (detailid),
  KEY master_eventid (master_eventid),
  KEY startdate (startdate),
  KEY enddate (enddate),
  KEY startdate_2 (startdate,enddate)
) TYPE=MyISAM;

--
-- Table structure for table `recurrence_dates`
--

DROP TABLE IF EXISTS recurrence_dates;
CREATE TABLE recurrence_dates (
  eventid int(11) NOT NULL default '0',
  type char(1) NOT NULL default '',
  recurstartdate date NOT NULL default '0000-00-00',
  recurstarttime time default NULL,
  recurenddate date NOT NULL default '0000-00-00',
  KEY eventid (eventid),
  KEY recurstartdate (recurstartdate),
  KEY recurenddate (recurenddate)
) TYPE=MyISAM;

--
-- Table structure for table `recurrence_rules`
--

DROP TABLE IF EXISTS recurrence_rules;
CREATE TABLE recurrence_rules (
  ruleid int(11) NOT NULL auto_increment,
  eventid int(11) NOT NULL default '0',
  type char(1) NOT NULL default '',
  freq char(1) NOT NULL default '',
  multiplier int(11) NOT NULL default '1',
  count int(11) default NULL,
  untildate date NOT NULL default '0000-00-00',
  untiltime time default NULL,
  wkst char(2) NOT NULL default 'SU',
  PRIMARY KEY  (ruleid),
  KEY untildate (untildate)
) TYPE=MyISAM;

--
-- Table structure for table `sponsors`
--

DROP TABLE IF EXISTS sponsors;
CREATE TABLE sponsors (
  sponsorid int(11) NOT NULL auto_increment,
  name varchar(255) binary NOT NULL default '',
  phone varchar(255) binary default NULL,
  email varchar(255) binary default NULL,
  link varchar(255) binary default NULL,
  creator varchar(20) binary NOT NULL default '',
  publicf char(1) default NULL,
  PRIMARY KEY  (sponsorid),
  KEY name (name(10)),
  KEY creator (creator),
  KEY public (publicf)
) TYPE=MyISAM;

--
-- Table structure for table `subscriptions`
--

DROP TABLE IF EXISTS subscriptions;
CREATE TABLE subscriptions (
  userid int(11) NOT NULL default '0',
  calendarid int(11) NOT NULL default '0',
  KEY userid (userid),
  KEY calendarid (calendarid)
) TYPE=MyISAM;

--
-- Table structure for table `synchstate`
--

DROP TABLE IF EXISTS synchstate;
CREATE TABLE synchstate (
  eventid int(11) NOT NULL default '0',
  userid int(11) NOT NULL default '0',
  guid varchar(255) NOT NULL default '',
  state int(11) NOT NULL default '0',
  KEY ssevi (eventid),
  KEY ssui (userid),
  KEY ssstate (state)
) TYPE=MyISAM;

--
-- Table structure for table `tokens`
--

DROP TABLE IF EXISTS tokens;
CREATE TABLE tokens (
  tokenid int(11) NOT NULL auto_increment,
  token varchar(255) NOT NULL default '',
  PRIMARY KEY  (tokenid),
  UNIQUE KEY token (token),
  KEY tokenidx (token)
) TYPE=MyISAM;

--
-- Table structure for table `users`
--

DROP TABLE IF EXISTS users;
CREATE TABLE users (
  userid int(11) NOT NULL auto_increment,
  username varchar(20) NOT NULL default '',
  created datetime default NULL,
  last_logon datetime default NULL,
  last_access datetime default NULL,
  last_modify datetime default NULL,
  PRIMARY KEY  (userid),
  KEY username (username)
) TYPE=MyISAM;

